LangChain.Config (LangChain v0.6.0)

Copy Markdown View Source

Utility that handles interaction with the application's configuration.

Summary

Functions

Resolves the given key from the application's configuration returning the wrapped expanded value. If the value is a function it gets evaluated, if the value is a tuple of three elements it gets applied.

Functions

resolve(key, default \\ nil)

@spec resolve(atom(), any()) :: any()

Resolves the given key from the application's configuration returning the wrapped expanded value. If the value is a function it gets evaluated, if the value is a tuple of three elements it gets applied.