LangChain.Tools.DeepResearch.ResearchRequest (LangChain v0.6.0)

Copy Markdown View Source

Represents a Deep Research request sent to the OpenAI API.

This schema defines the structure of a research request including the query, model selection, and various configuration options.

Summary

Functions

Creates a changeset for a research request.

Converts the research request to the format expected by the OpenAI API.

Types

t()

@type t() :: %LangChain.Tools.DeepResearch.ResearchRequest{
  background: boolean(),
  max_output_tokens: integer() | nil,
  max_tool_calls: integer() | nil,
  model: String.t(),
  query: String.t(),
  summary: String.t(),
  system_message: String.t() | nil,
  temperature: float()
}

Functions

changeset(request \\ %__MODULE__{}, attrs)

@spec changeset(t(), map()) :: Ecto.Changeset.t()

Creates a changeset for a research request.

to_api_format(request)

@spec to_api_format(t()) :: map()

Converts the research request to the format expected by the OpenAI API.