LangChain.Callbacks (LangChain v0.6.0)

Copy Markdown View Source

Defines the structure of callbacks and provides utilities for executing them.

See LangChain.Chains.ChainCallbacks for the list of callbacks that can be used.

Summary

Functions

Fire a named callback with the list of arguments to pass. Takes a list of callback handlers and will execute the callback for each handler that defines a handler function for it.

Functions

fire(callbacks, callback_name, arguments)

@spec fire([map()], atom(), [any()]) :: :ok | no_return()

Fire a named callback with the list of arguments to pass. Takes a list of callback handlers and will execute the callback for each handler that defines a handler function for it.