Represents the result of a file upload to an LLM provider.
Different providers return different types of file references:
- OpenAI and Anthropic return a
file_idstring - Google Gemini returns a
file_uriURL
At least one of file_id or file_uri will always be present.
The raw field contains the full provider response for accessing
provider-specific fields not covered by the struct.
Summary
Functions
Build a new FileResult and return an :ok/:error tuple with the result.
Build a new FileResult and return it or raise an error if invalid.